<?php

/**
 * Parallax controls
 */

function pae_add_parallax_control_to_widget( $element, $section_id, $args ) {

	if ( 'common' === $element->get_name() && '_section_style' === $section_id ) {

		$element->start_controls_section(
			'_section_parallax',
			array(
				'label' => esc_html__( 'Parallax', 'prime-addons-for-elementor' ),
				'tab'   => \Elementor\Controls_Manager::TAB_ADVANCED,
			)
		);

		$element->add_control(
			'parallax_item',
			array(
				'label'        => esc_html__( 'Parallax Item', 'prime-addons-for-elementor' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'default'      => '',
				'label_on'     => esc_html__( 'On', 'prime-addons-for-elementor' ),
				'label_off'    => esc_html__( 'Off', 'prime-addons-for-elementor' ),
			)
		);

		$element->add_control(
			'parallax_axis',
			array(
				'type'      => \Elementor\Controls_Manager::SELECT,
				'label'     => esc_html__( 'Parallax Axis', 'prime-addons-for-elementor' ),
				'default'   => 'y',
				'options'   => array(
					'y' => esc_html__( 'Y axis', 'prime-addons-for-elementor' ),
					'x' => esc_html__( 'X axis', 'prime-addons-for-elementor' ),
				),
				'condition' => array(
					'parallax_item' => 'yes',
				),
			)
		);

		$element->add_control(
			'parallax_momentum',
			array(
				'label'       => esc_html__( 'Momentum', 'prime-addons-for-elementor' ),
				'type'        => \Elementor\Controls_Manager::SLIDER,
				'description' => esc_html__( 'Value should be between -1 and +1', 'prime-addons-for-elementor' ),
				'default'     => array(
					'size' => 0.5,
				),
				'range'       => array(
					'px' => array(
						'min'  => -5,
						'max'  => 5,
						'step' => 0.1,
					),
				),
				'condition'   => array(
					'parallax_item' => 'yes',
				),
			)
		);

		$element->end_controls_section();

	}

}
add_action( 'elementor/element/after_section_end', 'pae_add_parallax_control_to_widget', 10, 3 );

function pae_add_parallax_control_attributes_to_elements( \Elementor\Element_Base $element ) {
	if ( ! $element->get_settings( 'parallax_item' ) == 'yes' ) {
		return;
	}

	$element->add_render_attribute(
		'_wrapper',
		array(
			'class'                  => 'parallax-layer',
			'data-parallax-momentum' => $element->get_settings( 'parallax_momentum' )['size'],
			'data-parallax-axis'     => $element->get_settings( 'parallax_axis' ),
		)
	);
}
add_action( 'elementor/frontend/element/before_render', 'pae_add_parallax_control_attributes_to_elements' );
add_action( 'elementor/frontend/widget/before_render', 'pae_add_parallax_control_attributes_to_elements' );
