<?php
/**
 * Widget: Blog Masonry
 *
 * @package Prime_Addons_Elementor
 */

namespace PrimeAddonsElementor\Elements\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\utils;
use Elementor\Core\Schemes\Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Core\Schemes\Typography;
use PrimeAddonsElementor\Elements\Helpers\Utils as PAE_Utils;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Blog Masonry widget class.
 *
 * @since 1.0.0
 */
class Blog_Masonry_Widget extends Widget_Base {
	public function __construct( $data = array(), $args = null ) {
		parent::__construct( $data, $args );

		wp_register_script( 'prime-addons-elementor-isotope', PAE_PLUGIN_URL . '/third-party/isotope/isotope.js', array(), '2.0.12' );
		wp_register_script( 'prime-addons-elementor-infinite-scroll', PAE_PLUGIN_URL . '/third-party/infinite-scroll/infinite-scroll.js', array(), '2.0.12' );
		wp_register_script( 'prime-addons-elementor-grid', PAE_PLUGIN_URL . '/assets/js/widgets/grid.js', array( 'elementor-frontend', 'prime-addons-elementor-isotope', 'imagesloaded', 'prime-addons-elementor-infinite-scroll' ), PAE_PLUGIN_VERSION, true );
	}

	public function get_name() {
		return 'pae-blog-masonry';
	}

	public function get_title() {
		return esc_html__( 'Blog Masonry', 'prime-addons-for-elementor' );
	}

	public function get_icon() {
		return 'eicon-posts-masonry';
	}

	public function get_categories() {
		return array( 'prime-addons-elementor' );
	}

	public function get_keywords() {
		return array( 'blog', 'post', 'masonry', 'grid' );
	}

	public function get_script_depends() {
		return array( 'prime-addons-elementor-grid' );
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_blog_masonry_post',
			array(
				'label' => esc_html__( 'Post Settings', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'number',
			array(
				'type'    => Controls_Manager::NUMBER,
				'label'   => esc_html__( 'Number of Posts', 'prime-addons-for-elementor' ),
				'default' => '6',
			)
		);

		// $this->add_control(
		// 	'columns',
		// 	array(
		// 		'label'   => esc_html__( 'Columns', 'prime-addons-for-elementor' ),
		// 		'type'    => Controls_Manager::SELECT,
		// 		'default' => '3',
		// 		'options' => array(
		// 			'2' => esc_html__( '2 Columns', 'prime-addons-for-elementor' ),
		// 			'3' => esc_html__( '3 Columns', 'prime-addons-for-elementor' ),
		// 			'4' => esc_html__( '4 Columns', 'prime-addons-for-elementor' ),
		// 			'5' => esc_html__( '5 Columns', 'prime-addons-for-elementor' ),
		// 		),
		// 	)
		// );

		// $this->add_responsive_control(
		// 	'gap',
		// 	array(
		// 		'label'          => esc_html__( 'Grid Gap', 'prime-addons-for-elementor' ),
		// 		'type'           => Controls_Manager::SLIDER,
		// 		'size_units'     => array( 'px' ),
		// 		'range'          => array(
		// 			'px' => array(
		// 				'max' => 100,
		// 			),
		// 		),
		// 		'default'        => array(
		// 			'size' => 30,
		// 			'unit' => 'px',
		// 		),
		// 		'tablet_default' => array(
		// 			'unit' => 'px',
		// 		),
		// 		'mobile_default' => array(
		// 			'unit' => 'px',
		// 		),
		// 		'selectors'      => array(
		// 			'{{WRAPPER}} .pae-masonry-blog' => 'column-gap: {{SIZE}}{{UNIT}};',
		// 		),
		// 	)
		// );

		$this->add_control(
			'post_meta_date',
			array(
				'label'        => esc_html__( 'Show Post Date', 'prime-addons-for-elementor' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'yes',
				'label_on'     => esc_html__( 'Yes', 'prime-addons-for-elementor' ),
				'label_off'    => esc_html__( 'No', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'post_meta_category',
			array(
				'label'        => esc_html__( 'Show Post Category', 'prime-addons-for-elementor' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'yes',
				'label_on'     => esc_html__( 'Yes', 'prime-addons-for-elementor' ),
				'label_off'    => esc_html__( 'No', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'post_meta_author',
			array(
				'label'        => esc_html__( 'Show Post Author', 'prime-addons-for-elementor' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'yes',
				'label_on'     => esc_html__( 'Yes', 'prime-addons-for-elementor' ),
				'label_off'    => esc_html__( 'No', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'show_excerpt',
			array(
				'label'        => esc_html__( 'Show Post Excerpt', 'prime-addons-for-elementor' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'yes',
				'label_on'     => esc_html__( 'Yes', 'prime-addons-for-elementor' ),
				'label_off'    => esc_html__( 'No', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'excerpt_length',
			array(
				'label'       => esc_html__( 'Excerpt Length', 'prime-addons-for-elementor' ),
				'description' => esc_html__( 'in words.', 'prime-addons-for-elementor' ),
				'type'        => Controls_Manager::NUMBER,
				'default'     => 20,
				'condition' => array(
					'show_excerpt' => 'yes',
				),
			)
		);

		$this->add_control(
			'pagination',
			array(
				'label'        => esc_html__( 'Enable Pagination', 'prime-addons-for-elementor' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'prime-addons-for-elementor' ),
				'label_off'    => esc_html__( 'No', 'prime-addons-for-elementor' ),
			)
		);

		$this->end_controls_section();

		do_action( 'pae_action_blog_masonry_controls', $this );

		$this->start_controls_section(
			'section_blog_masonry_layout',
			array(
				'label' => esc_html__( 'Layout', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_responsive_control(
			'columns',
			array(
				'type'        => Controls_Manager::SELECT,
				'label'       => esc_html__( 'Columns', 'prime-addons-for-elementor' ),
				'default' 			=> 3,
				'tablet_default'    => 2,
				'mobile_default'    => 1,
				'options'     => array(
					'1' => esc_html__( '1 Column', 'prime-addons-for-elementor' ),
					'2' => esc_html__( '2 Columns', 'prime-addons-for-elementor' ),
					'3' => esc_html__( '3 Columns', 'prime-addons-for-elementor' ),
					'4' => esc_html__( '4 Columns', 'prime-addons-for-elementor' ),
				),
			)
		);

		$this->add_responsive_control(
			'column_gap',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Column Gap', 'prime-addons-for-elementor' ),
				'selectors'   => array(					
					'{{WRAPPER}} .pae-masonry-container' => 'margin-inline: calc(-{{SIZE}}{{UNIT}} / 2);',
					'{{WRAPPER}} .pae-grid-item' => 'padding-inline: calc({{SIZE}}{{UNIT}} / 2);',
				),
				'default'     => array(
					'size' => 30,
				),
				'range'       => array(
					'px' => array(
						'min'  => 0,
						'max'  => 200,
						'step' => 1,
					),
				),
			)
		);

		$this->add_responsive_control(
			'row_gap',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Row Gap', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-grid-item' => 'padding-bottom: {{SIZE}}{{UNIT}};',
				),
				'default'     => array(
					'size' => 30,
				),
				'range'       => array(
					'px' => array(
						'min'  => 0,
						'max'  => 200,
						'step' => 1,
					),
				)
			)
		);


		$this->add_control(
			'shape',
			array(
				'type'    => Controls_Manager::SELECT,
				'label'   => esc_html__( 'Grid Shape', 'prime-addons-for-elementor' ),
				'default' => 'square',
				'options' => array(
					'square' => esc_html__( 'Square', 'prime-addons-for-elementor' ),
					'round'  => esc_html__( 'Round', 'prime-addons-for-elementor' ),
				),
			)
		);

		// $this->add_responsive_control(
		// 	'min_height',
		// 	array(
		// 		'type'        => Controls_Manager::SLIDER,
		// 		'label'       => esc_html__( 'Thumbnail Height', 'prime-addons-for-elementor' ),
		// 		'selectors'   => array(
		// 			'{{WRAPPER}} .pae-post-thumbnail' => 'height: {{SIZE}}{{UNIT}};',
		// 		),
		// 		'default'     => array(
		// 			'size' => 300,
		// 		),
		// 		'range'       => array(
		// 			'px' => array(
		// 				'min'  => 150,
		// 				'max'  => 1000,
		// 				'step' => 1,
		// 			),
		// 		),
		// 	)
		// );

		$this->end_controls_section();

		$this->start_controls_section(
		    'section_blog_masonry_title_style',
		    [
		        'label' => esc_html__( 'Title', 'prime-addons-for-elementor' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->start_controls_tabs( 'tabs_title_style' );

		$this->start_controls_tab(
			'tab_title_normal',
			array(
				'label' => esc_html__( 'Normal', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'title_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-post-title a' => 'color: {{VALUE}};',
				),
			)
		);

		 $this->end_controls_tab();

		 $this->start_controls_tab(
			'tab_title_hover',
			array(
				'label' => esc_html__( 'Hover', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'standard_title_hover_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-post-title:hover a' => 'color: {{VALUE}};',
				),
			)
		);

		 $this->end_controls_tab();
		 $this->end_controls_tabs();

		 $this->add_control(
			'title_divider',
			array(
				'type'      => Controls_Manager::DIVIDER,
			)
		);

		 $this->add_group_control(
			 Group_Control_Typography::get_type(),
			 array(
				 'name'      => 'title_typography',
				 'label'     => esc_html__( 'Typography', 'prime-addons-for-elementor' ),
				 'scheme'    => Typography::TYPOGRAPHY_2,
				 'selector'  => '{{WRAPPER}} .pae-post-title a',
			 )
		 );

		 $this->add_responsive_control(
			'title_margin',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Margin Top', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-post-title' => 'margin-top: {{SIZE}}{{UNIT}};',
				),
				'range'       => array(
					'px' => array(
						'min'  => 0,
						'max'  => 200,
						'step' => 1,
					),
				)
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'section_blog_masonry_category_style',
		    [
		        'label' => esc_html__( 'Category', 'prime-addons-for-elementor' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
				'condition'    => array(
					'post_meta_category' => 'yes',
				),
		    ]
		);
		$this->start_controls_tabs( 'tabs_cats_style' );

		$this->start_controls_tab(
			'tab_cats_normal',
			array(
				'label' => esc_html__( 'Normal', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'cats_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .category-link, {{WRAPPER}} .category-link a' => 'color: {{VALUE}};',
				),
				'condition'    => array(
					'post_meta_category' => 'yes',
				),
			)
		);

		 $this->end_controls_tab();

		 $this->start_controls_tab(
			'tab_cats_hover',
			array(
				'label' => esc_html__( 'Hover', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'standard_cats_hover_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .category-link:hover, {{WRAPPER}} .category-link:hover a' => 'color: {{VALUE}};',
				),
				'condition'    => array(
					'post_meta_category' => 'yes',
				),
			)
		);

		 $this->end_controls_tab();
		 $this->end_controls_tabs();

		 $this->add_control(
			'cats_divider',
			array(
				'type'      => Controls_Manager::DIVIDER,
			)
		);

		 $this->add_group_control(
			 Group_Control_Typography::get_type(),
			 array(
				 'name'      => 'cats_typography',
				 'label'     => esc_html__( 'Typography', 'prime-addons-for-elementor' ),
				 'scheme'    => Typography::TYPOGRAPHY_2,
				 'selector'  => '{{WRAPPER}} .category-link, {{WRAPPER}} .category-link a',
				'condition'    => array(
					'post_meta_category' => 'yes',
				),
			 )
		 );

		 $this->add_responsive_control(
			'cats_margin',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Margin Top', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .category-link' => 'margin-top: {{SIZE}}{{UNIT}};',
				),
				'range'       => array(
					'px' => array(
						'min'  => 0,
						'max'  => 200,
						'step' => 1,
					),
				),
				'condition'    => array(
					'post_meta_category' => 'yes',
				),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'section_blog_masonry_meta_style',
		    [
		        'label' => esc_html__( 'Meta Text', 'prime-addons-for-elementor' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
				'conditions' => [
					'relation' => 'or',
					'terms' => [
						[
							'name' => 'post_meta_date',
							'operator' => '==',
							'value' => 'yes'
						],
						[
							'name' => 'post_meta_author',
							'operator' => '==',
							'value' => 'yes'
						]
					]
				]
		    ]
		);

		$this->start_controls_tabs( 'tabs_meta_style' );

		$this->start_controls_tab(
			'tab_meta_normal',
			array(
				'label' => esc_html__( 'Normal', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'meta_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-post .meta .meta-item, {{WRAPPER}} .pae-post .meta a' => 'color: {{VALUE}};',
				),
				'conditions' => [
					'relation' => 'or',
					'terms' => [
						[
							'name' => 'post_meta_date',
							'operator' => '==',
							'value' => 'yes'
						],
						[
							'name' => 'post_meta_author',
							'operator' => '==',
							'value' => 'yes'
						]
					]
				]
			)
		);

		 $this->end_controls_tab();

		 $this->start_controls_tab(
			'tab_meta_hover',
			array(
				'label' => esc_html__( 'Hover', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'standard_meta_hover_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-post .meta a:hover' => 'color: {{VALUE}};',
				),
				'conditions' => [
					'relation' => 'or',
					'terms' => [
						[
							'name' => 'post_meta_date',
							'operator' => '==',
							'value' => 'yes'
						],
						[
							'name' => 'post_meta_author',
							'operator' => '==',
							'value' => 'yes'
						]
					]
				]
			)
		);

		 $this->end_controls_tab();
		 $this->end_controls_tabs();

		 $this->add_control(
			'meta_divider',
			array(
				'type'      => Controls_Manager::DIVIDER,
			)
		);

		 $this->add_group_control(
			 Group_Control_Typography::get_type(),
			 array(
				 'name'      => 'meta_typography',
				 'label'     => esc_html__( 'Typography', 'prime-addons-for-elementor' ),
				 'scheme'    => Typography::TYPOGRAPHY_2,
				 'selector'  => '{{WRAPPER}} .pae-post .meta, {{WRAPPER}} .pae-post .meta a',
				 'conditions' => [
					 'relation' => 'or',
					 'terms' => [
						 [
							 'name' => 'post_meta_date',
							 'operator' => '==',
							 'value' => 'yes'
						 ],
						 [
							 'name' => 'post_meta_author',
							 'operator' => '==',
							 'value' => 'yes'
						 ]
					 ]
				 ]
			 )
		 );

		 $this->add_responsive_control(
			'meta_margin',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Margin Top', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-post .meta' => 'margin-top: {{SIZE}}{{UNIT}};',
				),
				'range'       => array(
					'px' => array(
						'min'  => 0,
						'max'  => 200,
						'step' => 1,
					),
				),
				'conditions' => [
					'relation' => 'or',
					'terms' => [
						[
							'name' => 'post_meta_date',
							'operator' => '==',
							'value' => 'yes'
						],
						[
							'name' => 'post_meta_author',
							'operator' => '==',
							'value' => 'yes'
						]
					]
				]
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_blog_masonry_excerpt_style',
			array(
				'label' => esc_html__( 'Excerpt', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition' => array(
					'show_excerpt' => 'yes',
				),
			)
		);

		$this->add_control(
			'excerpt_color',
			array(
				'type'      => Controls_Manager::COLOR,
				'label'     => esc_html__( 'Excerpt Color', 'prime-addons-for-elementor' ),
				'default'   => '#666',
				'selectors' => array(
					'{{WRAPPER}} .pae-post-excerpt' => 'color: {{VALUE}}',
				),
				'condition' => array(
					'show_excerpt' => 'yes',
				),
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'excerpt_typography',
				'label'    => esc_html__( 'Excerpt Typography', 'prime-addons-for-elementor' ),
				'scheme'   => Typography::TYPOGRAPHY_2,
				'selector' => '{{WRAPPER}} .pae-post-excerpt p',
				'condition' => array(
					'show_excerpt' => 'yes',
				),
			)
		);

		$this->add_responsive_control(
		   'excerpt_margin',
		   array(
			   'type'        => Controls_Manager::SLIDER,
			   'label'       => esc_html__( 'Margin Top', 'prime-addons-for-elementor' ),
			   'selectors'   => array(
				   '{{WRAPPER}} .pae-post-excerpt' => 'margin-top: {{SIZE}}{{UNIT}};',
			   ),'
				default'     => array(
					'size' => 8,
				),
			   'range'       => array(
				   'px' => array(
					   'min'  => 0,
					   'max'  => 200,
					   'step' => 1,
				   ),
				),
				'condition' => array(
					'show_excerpt' => 'yes',
				),
		   )
	   );

		$this->end_controls_section();

		$this->start_controls_section(
			'section_blog_masonry_pagination_style',
			array(
				'label' => esc_html__( 'Pagination', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition'    => array(
					'pagination' => 'yes',
				),
			)
		);

		$this->start_controls_tabs( 'tabs_pagination_style' );

		$this->start_controls_tab(
			'tab_pagination_normal',
			array(
				'label' => esc_html__( 'Normal', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'pagination_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-pagenavi .page-numbers' => 'color: {{VALUE}};',
				),
				'condition'    => array(
					'pagination' => 'yes',
				),
			)
		);

		$this->add_control(
			'pagination_bg_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Background Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-pagenavi .page-numbers' => 'background-color: {{VALUE}};',
				),
				'condition'    => array(
					'pagination' => 'yes',
				),
			)
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_pagination_hover',
			array(
				'label' => esc_html__( 'Hover', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'pagination_hover_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-pagenavi .page-numbers:hover, {{WRAPPER}} .pae-pagenavi .page-numbers.current' => 'color: {{VALUE}};',
				),
				'condition'    => array(
					'pagination' => 'yes',
				),
			)
		);

		$this->add_control(
			'pagination_hover_bg_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Background Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-pagenavi .page-numbers:hover, {{WRAPPER}} .pae-pagenavi .page-numbers.current' => 'background-color: {{VALUE}};',
				),
				'condition'    => array(
					'pagination' => 'yes',
				),
			)
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_responsive_control(
			'pagination_margin',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Margin Top', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-pagenavi' => 'margin-top: {{SIZE}}{{UNIT}};',
				),
				'range'       => array(
					'px' => array(
						'min'  => 0,
						'max'  => 200,
						'step' => 1,
					),
				),
				'condition'    => array(
					'pagination' => 'yes',
				),
				'separator' => 'before',
			)
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$columns    		= isset( $settings['columns'] ) ? $settings['columns'] : 3;
		$columns_tablet 	= isset( $settings['columns_tablet'] ) ? $settings['columns_tablet'] : 2;
		$columns_mobile 	= isset( $settings['columns_mobile'] ) ? $settings['columns_mobile'] : 1;

		$this->add_render_attribute( 'pae-masonry-blog', 'class', 'pae-grids pae-masonry pae-masonry-container pae-masonry-blog' );
		$this->add_render_attribute( 'pae-masonry-blog', 'class', 'columns-sm-' . $columns_mobile . ' columns-md-' . $columns_tablet . ' columns-lg-' . $columns );
		?>

		<div <?php echo $this->get_render_attribute_string( 'pae-masonry-blog' ); ?>>
			<?php

			global $pae_loop;

			if ( ! isset( $pae_loop ) ) {
				$pae_loop = 1;
			} else {
				$pae_loop ++;
			}

			$paging          = 'paged' . $pae_loop;
			$paged           = isset( $_GET[ $paging ] ) ? absint( $_GET[ $paging ] ) : 1;
			$pagination_base = add_query_arg( $paging, '%#%' );

			$qargs = PAE_Utils::get_blog_query_args( $settings );

			$qargs['paged'] = $paged;

			$pae_blog_query = new \WP_Query( $qargs );
			?>

			<?php if ( $pae_blog_query->have_posts() ) : ?>

				<?php
				while ( $pae_blog_query->have_posts() ) :
					$pae_blog_query->the_post();
					?>
					<div class="pae-grid-item pae-post <?php echo esc_attr( $settings['shape'] )?>">
						<?php if ( has_post_thumbnail() ) : ?>
							<div class="pae-post-thumbnail"><a href="<?php the_permalink(); ?>">
								<img src="<?php echo esc_url( get_the_post_thumbnail_url( get_the_ID(), 'large' ) ); ?>" alt="" />
							</a>
							</div><!-- .pae-post-thumbnail -->
						<?php endif; ?>

						<div class="pae-post-entry">
							<?php if ( 'yes' === $settings['post_meta_category'] ) : ?>
								<span class="category-link" itemprop="category"><?php echo get_the_category_list( ', ' ); ?></span>
							<?php endif; ?>

							<h4 class="pae-post-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>

							<div class="meta">

								<?php if ( 'yes' === $settings['post_meta_date'] ) : ?>
									<a href="<?php the_permalink(); ?>" rel="bookmark" itemprop="datePublished" content="<?php echo esc_attr( get_the_date( get_option( 'date_format' ) ) ); ?>" class="meta-item"><?php echo esc_html( get_the_date( get_option( 'date_format' ) ) ); ?></a>
								<?php endif; ?>


								<?php if ( 'yes' === $settings['post_meta_author'] ) : ?>
									<span class="author meta-item" itemprop="author" itemscope itemtype="http://schema.org/Person"><?php echo esc_html__( 'By', 'prime-addons-for-elementor' ); ?> <?php the_author_posts_link(); ?></span>
								<?php endif; ?>

							</div><!-- .meta -->

							<?php if ( 'yes' === $settings['show_excerpt'] ) : ?>
								<div class="pae-post-excerpt">
									<?php
									$excerpt = PAE_Utils::get_post_excerpt( absint( $settings['excerpt_length'] ) );
									echo wp_kses_post( wpautop( $excerpt ) );
									?>
								</div>
							<?php endif; ?>

						</div><!-- .pae-post-entry -->

					</div><!-- .pae-post -->

				<?php endwhile; ?>

				<?php wp_reset_postdata(); ?>

				<?php else : ?>

					<div class="pae-standard-post"><p><?php esc_html_e( 'No Posts Found', 'prime-addons-for-elementor' ); ?></p></div>

			<?php endif; ?>
		</div>

		<?php if ( 'yes' === $settings['pagination'] ) : ?>
			<div class="pae-pagenavi">
				<?php
				echo paginate_links(
					array(
						'type'    => '',
						'base'    => $pagination_base,
						'format'  => '?' . $paging . '=%#%',
						'current' => max( 1, $pae_blog_query->get( 'paged' ) ),
						'total'   => $pae_blog_query->max_num_pages,
					)
				);
				?>
			</div>

		<?php endif; ?>

		<?php
	}
}
