<?php
/**
 * Widget: Blog Standard
 *
 * @package Prime_Addons_Elementor
 */

namespace PrimeAddonsElementor\Elements\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\utils;
use Elementor\Core\Schemes\Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Core\Schemes\Typography;
use PrimeAddonsElementor\Elements\Helpers\Utils as PAE_Utils;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Blog Standard widget class.
 *
 * @since 1.0.0
 */
class Blog_Standard_Widget extends Widget_Base {
	public function get_name() {
		return 'pae-blog-standard';
	}

	public function get_title() {
		return esc_html__( 'Blog Standard', 'prime-addons-for-elementor' );
	}

	public function get_icon() {
		return 'eicon-post-list';
	}

	public function get_categories() {
		return array( 'prime-addons-elementor' );
	}

	public function get_keywords() {
		return array( 'blog', 'post', 'standard' );
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_blog_standard_post',
			array(
				'label' => esc_html__( 'Post Settings', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'number',
			array(
				'type'    => Controls_Manager::NUMBER,
				'label'   => esc_html__( 'Number of Posts', 'prime-addons-for-elementor' ),
				'default' => '6',
			)
		);

		$this->add_control(
			'post_meta_date',
			array(
				'label'        => esc_html__( 'Show Post Date', 'prime-addons-for-elementor' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'yes',
				'label_on'     => esc_html__( 'Yes', 'prime-addons-for-elementor' ),
				'label_off'    => esc_html__( 'No', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'post_meta_category',
			array(
				'label'        => esc_html__( 'Show Post Category', 'prime-addons-for-elementor' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'yes',
				'label_on'     => esc_html__( 'Yes', 'prime-addons-for-elementor' ),
				'label_off'    => esc_html__( 'No', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'post_meta_author',
			array(
				'label'        => esc_html__( 'Show Post Author', 'prime-addons-for-elementor' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'yes',
				'label_on'     => esc_html__( 'Yes', 'prime-addons-for-elementor' ),
				'label_off'    => esc_html__( 'No', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'show_excerpt',
			array(
				'label'        => esc_html__( 'Show Post Excerpt', 'prime-addons-for-elementor' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'yes',
				'label_on'     => esc_html__( 'Yes', 'prime-addons-for-elementor' ),
				'label_off'    => esc_html__( 'No', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'excerpt_length',
			array(
				'label'       => esc_html__( 'Excerpt Length', 'prime-addons-for-elementor' ),
				'description' => esc_html__( 'in words.', 'prime-addons-for-elementor' ),
				'type'        => Controls_Manager::NUMBER,
				'default'     => 40,
				'condition' => array(
					'show_excerpt' => 'yes',
				),
			)
		);

		$this->add_control(
			'show_read_more',
			array(
				'label'        => esc_html__( 'Show Read More', 'prime-addons-for-elementor' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'yes',
				'label_on'     => esc_html__( 'Yes', 'prime-addons-for-elementor' ),
				'label_off'    => esc_html__( 'No', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'read_more_text',
			array(
				'label'       => esc_html__( 'Read More Text', 'prime-addons-for-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__( 'Read More', 'prime-addons-for-elementor' ),
				'condition' => array(
					'show_read_more' => 'yes',
				),
			)
		);

		$this->add_control(
			'pagination',
			array(
				'label'        => esc_html__( 'Enable Pagination', 'prime-addons-for-elementor' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'prime-addons-for-elementor' ),
				'label_off'    => esc_html__( 'No', 'prime-addons-for-elementor' ),
			)
		);

		$this->end_controls_section();

		do_action( 'pae_action_blog_standard_controls', $this );

		$this->start_controls_section(
			'section_standard_blog_listing_style',
			array(
				'label' => esc_html__( 'Boxed', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'boxed',
			array(
				'type'         => Controls_Manager::SWITCHER,
				'label'        => esc_html__( 'Boxed', 'prime-addons-for-elementor' ),
				'default'      => '',
				'label_on'     => esc_html__( 'Yes', 'prime-addons-for-elementor' ),
				'label_off'    => esc_html__( 'No', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'item_bg_color',
			array(
				'type'      => Controls_Manager::COLOR,
				'label'     => esc_html__( 'Background Color', 'prime-addons-for-elementor' ),
				'default'   => '#f8f8f8',
				'selectors' => array(
					'{{WRAPPER}} .pae-standard-blog.boxed .pae-post' => 'background: {{VALUE}}',
				),
				'condition' => array(
					'boxed' => 'yes',
				),
			)
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			array(
				'name'      => 'item_border',
				'selector'  => '{{WRAPPER}} .pae-standard-blog.boxed .pae-post',
				'separator' => 'before',
				'condition' => array(
					'boxed' => 'yes',
				),
			)
		);

		$this->add_control(
			'item_border_radius',
			array(
				'label'      => __( 'Border Radius', 'prime-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%' ),
				'selectors'  => array(
					'{{WRAPPER}} .pae-standard-blog.boxed .pae-post' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
				'condition'  => array(
					'boxed' => 'yes',
				),
			)
		);

		// $this->add_group_control(
		// 	Group_Control_Box_Shadow::get_type(),
		// 	array(
		// 		'name'      => 'item_box_shadow',
		// 		'selector'  => '{{WRAPPER}} .pae-standard-blog.boxed .pae-post',
		// 		'condition' => array(
		// 			'boxed' => 'yes',
		// 		),
		// 	)
		// );
		$this->end_controls_section();

		$this->start_controls_section(
			'section_blog_standard_thubmnail_style',
			array(
				'label' => esc_html__( 'Thumbnail', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'show_thumbnail',
			array(
				'label'        => esc_html__( 'Show Featured Image', 'prime-addons-for-elementor' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => '',
				'label_on'     => esc_html__( 'Yes', 'prime-addons-for-elementor' ),
				'label_off'    => esc_html__( 'No', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'thumbnail_alignment',
			array(
				'label'     => esc_html__( 'Alignment', 'prime-addons-for-elementor' ),
				'type'      => Controls_Manager::CHOOSE,
				'options'   => array(
					'left'  => array(
						'title' => esc_html__( 'Left', 'prime-addons-for-elementor' ),
						'icon'  => 'eicon-text-align-left',
					),
					'none'  => array(
						'title' => esc_html__( 'None', 'prime-addons-for-elementor' ),
						'icon'  => 'eicon-text-align-center',
					),
					'right' => array(
						'title' => esc_html__( 'Right', 'prime-addons-for-elementor' ),
						'icon'  => 'eicon-text-align-right',
					),
				),
				'default'   => 'none',
				'condition' => array(
					'show_thumbnail' => 'yes',
				),
			)
		);

		$this->add_responsive_control(
			'thumbnail_width',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Thumbnail Width', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-post-thumbnail' => 'width: {{SIZE}}{{UNIT}};',
				),
				// 'description' => esc_html__( 'You can adjust the thumbnail width for different devices. ', 'prime-addons-for-elementor' ),
				'default'     => array(
					'size' => 400,
				),
				'range'       => array(
					'px' => array(
						'min'  => 50,
						'max'  => 1200,
						'step' => 1,
					),
				),
				'conditions' => [
					'relation' => 'or',
					'terms' => [
						[
							'name' => 'thumbnail_alignment',
							'operator' => '==',
							'value' => 'left'
						],
						[
							'name' => 'thumbnail_alignment',
							'operator' => '==',
							'value' => 'right'
						]
					]
				]
			)
		);

		$this->add_responsive_control(
			'thumbnail_height',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Thumbnail Height', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-post-thumbnail' => 'height: {{SIZE}}{{UNIT}};',
				),
				// 'description' => esc_html__( 'You can adjust the thumbnail height for different devices. ', 'prime-addons-for-elementor' ),
				'default'     => array(
					'size' => 400,
				),
				'range'       => array(
					'px' => array(
						'min'  => 180,
						'max'  => 1200,
						'step' => 1,
					),
				),
				'condition' => array(
					'show_thumbnail' => 'yes',
				),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_blog_standard_title_style',
			array(
				'label' => esc_html__( 'Title', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->start_controls_tabs( 'tabs_title_style' );

		$this->start_controls_tab(
			'tab_title_normal',
			array(
				'label' => esc_html__( 'Normal', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'title_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-post-title a' => 'color: {{VALUE}};',
				),
			)
		);

		 $this->end_controls_tab();

		 $this->start_controls_tab(
			'tab_title_hover',
			array(
				'label' => esc_html__( 'Hover', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'standard_title_hover_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-post-title:hover a' => 'color: {{VALUE}};',
				),
			)
		);

		 $this->end_controls_tab();
		 $this->end_controls_tabs();

		 $this->add_control(
			'title_divider',
			array(
				'type'      => Controls_Manager::DIVIDER,
			)
		);

		 $this->add_group_control(
			 Group_Control_Typography::get_type(),
			 array(
				 'name'      => 'title_typography',
				 'label'     => esc_html__( 'Typography', 'prime-addons-for-elementor' ),
				 'scheme'    => Typography::TYPOGRAPHY_2,
				 'selector'  => '{{WRAPPER}} .pae-post-title a',
			 )
		 );

		 $this->add_responsive_control(
			'title_margin',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Margin Top', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-post-title' => 'margin-top: {{SIZE}}{{UNIT}};',
				),
				'range'       => array(
					'px' => array(
						'min'  => 0,
						'max'  => 200,
						'step' => 1,
					),
				)
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_blog_standard_meta_style',
			array(
				'label' => esc_html__( 'Meta', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'conditions' => [
					'relation' => 'or',
					'terms' => [
						[
							'name' => 'post_meta_date',
							'operator' => '==',
							'value' => 'yes'
						],
						[
							'name' => 'post_meta_category',
							'operator' => '==',
							'value' => 'yes'
						],
						[
							'name' => 'post_meta_author',
							'operator' => '==',
							'value' => 'yes'
						]
					]
				]
			)
		);

		$this->start_controls_tabs( 'tabs_meta_style' );

		$this->start_controls_tab(
			'tab_meta_normal',
			array(
				'label' => esc_html__( 'Normal', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'meta_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-post .meta .meta-item, {{WRAPPER}} .pae-post .meta a' => 'color: {{VALUE}};',
				),
				'conditions' => [
					'relation' => 'or',
					'terms' => [
						[
							'name' => 'post_meta_date',
							'operator' => '==',
							'value' => 'yes'
						],
						[
							'name' => 'post_meta_category',
							'operator' => '==',
							'value' => 'yes'
						],
						[
							'name' => 'post_meta_author',
							'operator' => '==',
							'value' => 'yes'
						]
					]
				]
			)
		);

		 $this->end_controls_tab();

		 $this->start_controls_tab(
			'tab_meta_hover',
			array(
				'label' => esc_html__( 'Hover', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'standard_meta_hover_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-post .meta a:hover' => 'color: {{VALUE}};',
				),
				'conditions' => [
					'relation' => 'or',
					'terms' => [
						[
							'name' => 'post_meta_date',
							'operator' => '==',
							'value' => 'yes'
						],
						[
							'name' => 'post_meta_category',
							'operator' => '==',
							'value' => 'yes'
						],
						[
							'name' => 'post_meta_author',
							'operator' => '==',
							'value' => 'yes'
						]
					]
				]
			)
		);

		 $this->end_controls_tab();
		 $this->end_controls_tabs();

		 $this->add_control(
			'meta_divider',
			array(
				'type'      => Controls_Manager::DIVIDER,
			)
		);

		 $this->add_group_control(
			 Group_Control_Typography::get_type(),
			 array(
				 'name'      => 'meta_typography',
				 'label'     => esc_html__( 'Typography', 'prime-addons-for-elementor' ),
				 'scheme'    => Typography::TYPOGRAPHY_2,
				 'selector'  => '{{WRAPPER}} .pae-post .meta .meta-item, {{WRAPPER}} .pae-post .meta a',
				 'conditions' => [
					 'relation' => 'or',
					 'terms' => [
						 [
							 'name' => 'post_meta_date',
							 'operator' => '==',
							 'value' => 'yes'
						 ],
						 [
							 'name' => 'post_meta_category',
							 'operator' => '==',
							 'value' => 'yes'
						 ],
						 [
							 'name' => 'post_meta_author',
							 'operator' => '==',
							 'value' => 'yes'
						 ]
					 ]
				 ]
			 )
		 );

		 $this->add_responsive_control(
			'meta_margin',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Margin Top', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-post .meta' => 'margin-top: {{SIZE}}{{UNIT}};',
				),
				'range'       => array(
					'px' => array(
						'min'  => 0,
						'max'  => 200,
						'step' => 1,
					),
				),
				'conditions' => [
					'relation' => 'or',
					'terms' => [
						[
							'name' => 'post_meta_date',
							'operator' => '==',
							'value' => 'yes'
						],
						[
							'name' => 'post_meta_category',
							'operator' => '==',
							'value' => 'yes'
						],
						[
							'name' => 'post_meta_author',
							'operator' => '==',
							'value' => 'yes'
						]
					]
				]
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_blog_standard_excerpt_style',
			array(
				'label' => esc_html__( 'Excerpt', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition'    => array(
					'show_excerpt' => 'yes',
				),
			)
		);

		$this->add_control(
			'excerpt_color',
			array(
				'type'      => Controls_Manager::COLOR,
				'label'     => esc_html__( 'Excerpt Color', 'prime-addons-for-elementor' ),
				'selectors' => array(
					'{{WRAPPER}} .pae-post-excerpt' => 'color: {{VALUE}}',
				),
				'condition'    => array(
					'show_excerpt' => 'yes',
				),
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'excerpt_typography',
				'label'    => esc_html__( 'Excerpt Typography', 'prime-addons-for-elementor' ),
				'scheme'   => Typography::TYPOGRAPHY_2,
				'selector' => '{{WRAPPER}} .pae-post-excerpt p',
				'condition'    => array(
					'show_excerpt' => 'yes',
				),
			)
		);

		$this->add_responsive_control(
			'excerpt_margin',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Margin Top', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-post-excerpt' => 'margin-top: {{SIZE}}{{UNIT}};',
				),
				'range'       => array(
					'px' => array(
						'min'  => 0,
						'max'  => 200,
						'step' => 1,
					),
				),
				'condition'    => array(
					'show_excerpt' => 'yes',
				),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_blog_standard_read_more_style',
			array(
				'label' => esc_html__( 'Read More', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition'    => array(
					'show_read_more' => 'yes',
				),
			)
		);

		$this->start_controls_tabs( 'tabs_read_more_style' );

		$this->start_controls_tab(
			'tab_read_more_normal',
			array(
				'label' => esc_html__( 'Normal', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'read_more_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .read-more' => 'color: {{VALUE}};',
				),
				'condition'    => array(
					'show_read_more' => 'yes',
				),
			)
		);

		 $this->end_controls_tab();

		 $this->start_controls_tab(
			'tab_read_more_hover',
			array(
				'label' => esc_html__( 'Hover', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'standard_read_more_hover_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .read-more:hover' => 'color: {{VALUE}};',
				),
				'condition'    => array(
					'show_read_more' => 'yes',
				),
			)
		);

		 $this->end_controls_tab();
		 $this->end_controls_tabs();

		 $this->add_control(
			'read_more_divider',
			array(
				'type'      => Controls_Manager::DIVIDER,
			)
		);

		 $this->add_group_control(
			 Group_Control_Typography::get_type(),
			 array(
				 'name'      => 'read_more_typography',
				 'label'     => esc_html__( 'Typography', 'prime-addons-for-elementor' ),
				 'scheme'    => Typography::TYPOGRAPHY_2,
				 'selector'  => '{{WRAPPER}} .read-more',
				 'condition'    => array(
					 'show_read_more' => 'yes',
				 ),
			 )
		 );

		 $this->add_responsive_control(
			'read_more_margin',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Margin Top', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-post-footer' => 'margin-top: {{SIZE}}{{UNIT}};',
				),
				'range'       => array(
					'px' => array(
						'min'  => 0,
						'max'  => 200,
						'step' => 1,
					),
				),
				'condition'    => array(
					'show_read_more' => 'yes',
				),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_blog_standard_pagination_style',
			array(
				'label' => esc_html__( 'Pagination', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition'    => array(
					'pagination' => 'yes',
				),
			)
		);

		$this->start_controls_tabs( 'tabs_pagination_style' );

		$this->start_controls_tab(
			'tab_pagination_normal',
			array(
				'label' => esc_html__( 'Normal', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'pagination_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-pagenavi .page-numbers' => 'color: {{VALUE}};',
				),
				'condition'    => array(
					'pagination' => 'yes',
				),
			)
		);

		$this->add_control(
			'pagination_bg_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Background Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-pagenavi .page-numbers' => 'background-color: {{VALUE}};',
				),
				'condition'    => array(
					'pagination' => 'yes',
				),
			)
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_pagination_hover',
			array(
				'label' => esc_html__( 'Hover', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'pagination_hover_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-pagenavi .page-numbers:hover, {{WRAPPER}} .pae-pagenavi .page-numbers.current' => 'color: {{VALUE}};',
				),
				'condition'    => array(
					'pagination' => 'yes',
				),
			)
		);

		$this->add_control(
			'pagination_hover_bg_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Background Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-pagenavi .page-numbers:hover, {{WRAPPER}} .pae-pagenavi .page-numbers.current' => 'background-color: {{VALUE}};',
				),
				'condition'    => array(
					'pagination' => 'yes',
				),
			)
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_responsive_control(
			'pagination_margin',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Margin Top', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-pagenavi' => 'margin-top: {{SIZE}}{{UNIT}};',
				),
				'range'       => array(
					'px' => array(
						'min'  => 0,
						'max'  => 200,
						'step' => 1,
					),
				),
				'condition'    => array(
					'pagination' => 'yes',
				),
				'separator' => 'before',
			)
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$this->add_render_attribute( 'pae-standard-blog', 'class', 'pae-standard-blog' );
		$this->add_render_attribute( 'pae-standard-blog', 'class', 'thumbnail-' . $settings['thumbnail_alignment'] );
		if ( 'yes' === $settings['boxed'] ) {
			$this->add_render_attribute( 'pae-standard-blog', 'class', 'boxed' );
		}
		?>
		<div <?php echo $this->get_render_attribute_string( 'pae-standard-blog' ); ?>>
			<?php

			global $pae_loop;

			if ( ! isset( $pae_loop ) ) {
				$pae_loop = 1;
			} else {
				$pae_loop ++;
			}

			$paging          = 'paged' . $pae_loop;
			$paged           = isset( $_GET[ $paging ] ) ? absint( $_GET[ $paging ] ) : 1;
			$pagination_base = add_query_arg( $paging, '%#%' );

			$qargs = PAE_Utils::get_blog_query_args( $settings );

			$qargs['paged'] = $paged;

			$pae_blog_query = new \WP_Query( $qargs );
			?>

			<?php if ( $pae_blog_query->have_posts() ) : ?>

				<?php
				while ( $pae_blog_query->have_posts() ) :
					$pae_blog_query->the_post();
					?>
					<?php
					$no_thumbnail = ! has_post_thumbnail() ? 'pae-no-thumbnail' : '';
					?>
					<div class="pae-post">
						<?php if ( 'yes' === $settings['show_thumbnail'] && has_post_thumbnail() ) : ?>
							<div class="pae-post-thumbnail" style="background-image:url(<?php echo esc_url( get_the_post_thumbnail_url( get_the_ID(), 'large' ) ); ?>);"><a href="<?php the_permalink(); ?>"></a>
							</div><!-- .pae-post-thumbnail -->
						<?php endif; ?>

						<div class="pae-post-entry <?php echo esc_attr( $no_thumbnail ); ?>">

							<h4 class="pae-post-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>

							<div class="meta">

								<?php if ( 'yes' === $settings['post_meta_date'] ) : ?>
									<a href="<?php the_permalink(); ?>" rel="bookmark" itemprop="datePublished" content="<?php echo esc_attr( get_the_date( get_option( 'date_format' ) ) ); ?>" class="meta-item"><?php echo esc_html( get_the_date( get_option( 'date_format' ) ) ); ?></a>
								<?php endif; ?>

								<?php if ( 'yes' === $settings['post_meta_category'] ) : ?>
									<span class="category meta-item" itemprop="category"><?php echo esc_html__( 'In', 'prime-addons-for-elementor' ) . ' ' . get_the_category_list( ', ' ); ?></span>
								<?php endif; ?>

								<?php if ( 'yes' === $settings['post_meta_author'] ) : ?>
									<span class="author meta-item" itemprop="author" itemscope itemtype="http://schema.org/Person"><?php echo esc_html__( 'By', 'prime-addons-for-elementor' ); ?> <?php the_author_posts_link(); ?></span>
								<?php endif; ?>

							</div><!-- .meta -->

							<?php if ( 'yes' === $settings['show_excerpt'] ) : ?>
								<div class="pae-post-excerpt">
									<?php
									$excerpt = PAE_Utils::get_post_excerpt( absint( $settings['excerpt_length'] ) );
									echo wp_kses_post( wpautop( $excerpt ) );
									?>
								</div>
							<?php endif; ?>

							<?php if ( 'yes' === $settings['show_read_more'] ) : ?>
								<footer class="pae-post-footer">
									<a href="<?php the_permalink(); ?>" class="read-more"><?php echo esc_html( $settings['read_more_text'] ); ?></a>
								</footer>
							<?php endif; ?>

						</div><!-- .pae-post-entry -->

					</div><!-- .pae-post -->

				<?php endwhile; ?>

				<?php wp_reset_postdata(); ?>

				<?php else : ?>

					<div class="pae-standard-post"><p><?php esc_html_e( 'No Posts Found', 'prime-addons-for-elementor' ); ?></p></div>

			<?php endif; ?>
		</div>

		<?php if ( 'yes' === $settings['pagination'] ) : ?>
			<div class="pae-pagenavi">
				<?php
				echo paginate_links(
					array(
						'type'    => '',
						'base'    => $pagination_base,
						'format'  => '?' . $paging . '=%#%',
						'current' => max( 1, $pae_blog_query->get( 'paged' ) ),
						'total'   => $pae_blog_query->max_num_pages,
					)
				);
				?>
			</div>

		<?php endif; ?>

		<?php
	}
}
