<?php
/**
 * Widget: EDD Product Carousel
 *
 * @package Prime_Addons_Elementor
 */

namespace PrimeAddonsElementor\Elements\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\utils;
use Elementor\Core\Schemes\Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Core\Schemes\Typography;
use PrimeAddonsElementor\Elements\Helpers\Utils as PAE_Utils;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * EDD Product Carousel widget class.
 *
 * @since 1.0.0
 */
class EDD_Product_Carousel_Widget extends Widget_Base {
	public function __construct( $data = array(), $args = null ) {
		parent::__construct( $data, $args );

		wp_register_script( 'prime-addons-elementor-carousel', PAE_PLUGIN_URL . '/assets/js/widgets/carousel.js', array( 'elementor-frontend', 'imagesloaded' ), PAE_PLUGIN_VERSION, true );
	}

	public function get_name() {
		return 'pae-edd-product-carousel';
	}

	public function get_title() {
		return esc_html__( 'EDD Product Carousel', 'prime-addons-for-elementor' );
	}

	public function get_icon() {
		return 'eicon-media-carousel';
	}

	public function get_categories() {
		return array( 'prime-addons-elementor' );
	}

	public function get_keywords() {
		return array( 'edd', 'carousel', 'download', 'easy', 'digital' );
	}

	public function get_script_depends() {
		return array( 'swiper', 'prime-addons-elementor-carousel' );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'section_edd_product_carousel_post',
			array(
				'label' => esc_html__( 'Settings', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'number',
			array(
				'type'    => Controls_Manager::NUMBER,
				'label'   => esc_html__( 'Number of Products', 'prime-addons-for-elementor' ),
				'default' => '6',
			)
		);

		$this->add_control(
			'show_price',
			array(
				'label'        => esc_html__( 'Show Price', 'prime-addons-for-elementor' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'yes',
				'label_on'  => esc_html__( 'On', 'prime-addons-for-elementor' ),
				'label_off' => esc_html__( 'Off', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'show_button',
			array(
				'label'        => esc_html__( 'Show Cart Button', 'prime-addons-for-elementor' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => '',
				'label_on'  => esc_html__( 'On', 'prime-addons-for-elementor' ),
				'label_off' => esc_html__( 'Off', 'prime-addons-for-elementor' ),
			)
		);

		$this->end_controls_section();

		do_action( 'pae_action_edd_product_carousel_after_product_settings_controls', $this );

		$this->start_controls_section(
			'section_edd_products_query',
			array(
				'label' => esc_html__( 'Query', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'categories',
			array(
				'label'       => esc_html__( 'Categories', 'prime-addons-for-elementor' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT2,
				'multiple'    => true,
				'options'     => PAE_Utils::get_terms_options( 'download_category' ),
			)
		);

		$this->add_control(
			'orderby',
			array(
				'type'    => Controls_Manager::SELECT,
				'label'   => esc_html__( 'Order By', 'prime-addons-for-elementor' ),
				'default' => 'date',
				'options' => PAE_Utils::get_post_orderby_options(),
			)
		);

		$this->add_control(
			'order',
			array(
				'label'   => esc_html__( 'Order', 'prime-addons-for-elementor' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'desc',
				'options' => PAE_Utils::get_post_order_options(),
			)
		);

		$this->end_controls_section();

		do_action( 'pae_action_edd_product_carousel_after_query_settings_controls', $this );

		$this->start_controls_section(
			'section_edd_product_carousel_layout',
			array(
				'label' => esc_html__( 'Layout', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'grid_style',
			array(
				'label'   => esc_html__( 'Grid Style', 'prime-addons-for-elementor' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'default',
				'options' => array(
					'default' => esc_html__( 'Standard', 'prime-addons-for-elementor' ),
					'overlay' => esc_html__( 'Overlay', 'prime-addons-for-elementor' ),
				),
			)
		);
		
		$this->add_control(
			'shape',
			array(
				'type'    => Controls_Manager::SELECT,
				'label'   => esc_html__( 'Grid Shape', 'prime-addons-for-elementor' ),
				'default' => 'square',
				'options' => array(
					'square' => esc_html__( 'Square', 'prime-addons-for-elementor' ),
					'round'  => esc_html__( 'Round', 'prime-addons-for-elementor' ),
				),
			)
		);

		$this->add_control(
			'boxed',
			array(
				'type'         => Controls_Manager::SWITCHER,
				'label'        => esc_html__( 'Boxed Style', 'prime-addons-for-elementor' ),
				'default'      => '',
				'label_on'     => esc_html__( 'On', 'prime-addons-for-elementor' ),
				'label_off'    => esc_html__( 'Off', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'image_size',
			array(
				'type'    => Controls_Manager::SELECT,
				'label'   => esc_html__( 'Image Size', 'prime-addons-for-elementor' ),
				'default' => 'medium_large',
				'options' => PAE_Utils::get_image_sizes_options(),
			)
		);

		$this->add_control(
			'hover_effect',
			array(
				'label'        => esc_html__( 'Hover Effect', 'prime-addons-for-elementor' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => '',
				'label_on'  => esc_html__( 'On', 'prime-addons-for-elementor' ),
				'label_off' => esc_html__( 'Off', 'prime-addons-for-elementor' ),
			)
		);		

		$this->end_controls_section();

		do_action( 'pae_action_edd_product_carousel_after_layout_settings_controls', $this );

		$this->start_controls_section(
			'section_edd_carousel_column_style',
			array(
				'label' => esc_html__( 'Boxed', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'conditions' => [
					'relation' => 'and',
					'terms' => [
						[
							'name' => 'grid_style',
							'operator' => '==',
							'value' => 'default'
						],
						[
							'name' => 'boxed',
							'operator' => '==',
							'value' => 'yes'
						]
					]
				]
			)
		);

		$this->add_control(
			'item_bg_color',
			array(
				'type'      => Controls_Manager::COLOR,
				'label'     => esc_html__( 'Background Color', 'prime-addons-for-elementor' ),
				'default'   => '#f9f9f9',
				'selectors' => array(
					'{{WRAPPER}} .pae-carousel .swiper-slide.boxed' => 'background: {{VALUE}}',
				),
				'conditions' => [
					'relation' => 'and',
					'terms' => [
						[
							'name' => 'grid_style',
							'operator' => '==',
							'value' => 'default'
						],
						[
							'name' => 'boxed',
							'operator' => '==',
							'value' => 'yes'
						]
					]
				]
			)
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			array(
				'name'      => 'item_border',
				'selector'  => '{{WRAPPER}} .pae-carousel .swiper-slide.boxed',				
				'conditions' => [
					'relation' => 'and',
					'terms' => [
						[
							'name' => 'grid_style',
							'operator' => '==',
							'value' => 'default'
						],
						[
							'name' => 'boxed',
							'operator' => '==',
							'value' => 'yes'
						]
					]
				]
			)
		);

		$this->add_control(
			'item_border_radius',
			array(
				'label'      => __( 'Border Radius', 'prime-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%' ),
				'selectors'  => array(
					'{{WRAPPER}} .pae-carousel .swiper-slide' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),				
				'conditions' => [
					'relation' => 'and',
					'terms' => [
						[
							'name' => 'grid_style',
							'operator' => '==',
							'value' => 'default'
						],
						[
							'name' => 'boxed',
							'operator' => '==',
							'value' => 'yes'
						]
					]
				]
			)
		);

		// $this->add_group_control(
		// 	Group_Control_Box_Shadow::get_type(),
		// 	array(
		// 		'name'      => 'item_box_shadow',
		// 		'selector'  => '{{WRAPPER}} .pae-carousel .swiper-slide.boxed',
		//		
		// 'conditions' => [
		// 	'relation' => 'and',
		// 	'terms' => [
		// 		[
		// 			'name' => 'grid_style',
		// 			'operator' => '==',
		// 			'value' => 'default'
		// 		],
		// 		[
		// 			'name' => 'boxed',
		// 			'operator' => '==',
		// 			'value' => 'yes'
		// 		]
		// 	]
		// ]
		// 	)
		// );

		$this->end_controls_section();

		do_action( 'pae_action_edd_product_carousel_after_column_style_controls', $this );

		$this->start_controls_section(
			'section_edd_product_carousel_title_style',
			array(
				'label' => esc_html__( 'Title', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->start_controls_tabs( 'tabs_title_style' );

		$this->start_controls_tab(
			'tab_title_normal',
			array(
				'label' => esc_html__( 'Normal', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'title_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-carousel-title a' => 'color: {{VALUE}};',
				),
			)
		);

		 $this->end_controls_tab();

		 $this->start_controls_tab(
			'tab_title_hover',
			array(
				'label' => esc_html__( 'Hover', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'standard_title_hover_color',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-carousel-title:hover a' => 'color: {{VALUE}};',
				),
			)
		);

		 $this->end_controls_tab();
		 $this->end_controls_tabs();

		 $this->add_control(
			'title_divider',
			array(
				'type'      => Controls_Manager::DIVIDER,
			)
		);

		 $this->add_group_control(
			 Group_Control_Typography::get_type(),
			 array(
				 'name'      => 'title_typography',
				 'label'     => esc_html__( 'Typography', 'prime-addons-for-elementor' ),
				 'scheme'    => Typography::TYPOGRAPHY_2,
				 'selector'  => '{{WRAPPER}} .pae-carousel-title a',
			 )
		 );

		 $this->add_responsive_control(
			'title_margin',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Margin Top', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-carousel-title' => 'margin-top: {{SIZE}}{{UNIT}};',
				),
				'default'     => array(
					'size' => 15,
				),
				'range'       => array(
					'px' => array(
						'min'  => 0,
						'max'  => 200,
						'step' => 1,
					),
				)
			)
		);

		$this->end_controls_section();

		do_action( 'pae_action_edd_product_carousel_after_title_style_controls', $this );

		$this->start_controls_section(
			'section_edd_product_carousel_price_style',
			array(
				'label' => esc_html__( 'Price', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'conditions' => [
					'relation' => 'and',
					'terms' => [
						[
							'name' => 'show_price',
							'operator' => '==',
							'value' => 'yes'
						]
					]
				]
			)
		);

		$this->add_control(
			'price_color',
			array(
				'type'      => Controls_Manager::COLOR,
				'label'     => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'selectors' => array(
					'{{WRAPPER}} .pae-carousel-price' => 'color: {{VALUE}}',
				),
				'conditions' => [
					'relation' => 'and',
					'terms' => [
						[
							'name' => 'show_price',
							'operator' => '==',
							'value' => 'yes'
						]
					]
				]
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'price_typography',
				'label'    => esc_html__( 'Typography', 'prime-addons-for-elementor' ),
				'scheme'   => Typography::TYPOGRAPHY_2,
				'selector' => '{{WRAPPER}} .pae-carousel-price',
				'conditions' => [
					'relation' => 'and',
					'terms' => [
						[
							'name' => 'show_price',
							'operator' => '==',
							'value' => 'yes'
						]
					]
				]
			)
		);		

		$this->add_responsive_control(
			'price_margin',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Margin Top', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-carousel-price' => 'margin-top: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .overlay .pae-carousel-price' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				),
				'default'     => array(
					'size' => 8,
				),
				'range'       => array(
					'px' => array(
						'min'  => 0,
						'max'  => 200,
						'step' => 1,
					),
				),
				'conditions' => [
					'relation' => 'and',
					'terms' => [
						[
							'name' => 'show_price',
							'operator' => '==',
							'value' => 'yes'
						]
					]
				]
			)
		);

		$this->end_controls_section();

		do_action( 'pae_action_edd_product_carousel_after_price_style_controls', $this );

		$this->start_controls_section(
			'section_edd_product_carousel_overlay_style',
			array(
				'label' => esc_html__( 'Overlay', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'overlay_color',
			array(
				'type'      => Controls_Manager::COLOR,
				'label'     => esc_html__( 'Overlay Color', 'prime-addons-for-elementor' ),
				'selectors' => array(
					'{{WRAPPER}} .overlay' => 'background-color: {{VALUE}}',
				),
			)
		);

		$this->end_controls_section();

		do_action( 'pae_action_edd_product_carousel_after_overlay_style_controls', $this );

		// $this->start_controls_section(
		// 	'section_edd_product_carousel_icon_style',
		// 	array(
		// 		'label' => esc_html__( 'Icon', 'prime-addons-for-elementor' ),
		// 		'tab'   => Controls_Manager::TAB_STYLE,
		// 	)
		// );

		// $this->add_control(
		// 	'cart_icon',
		// 	[
		// 		'label' => esc_html__( 'Cart Icon', 'prime-addons-for-elementor' ),
		// 		'type' => Controls_Manager::HEADING,
		// 		'condition'    => array(
		// 			'show_button' => 'yes'
		// 		)
		// 	]
		// );

		// $this->add_control(
		// 	'cart_icon_color',
		// 	array(
		// 		'type'      => Controls_Manager::COLOR,
		// 		'label'     => esc_html__( 'Icon Color', 'prime-addons-for-elementor' ),
		// 		'selectors' => array(
		// 			'{{WRAPPER}} .pae-carousel-button.buy' => 'color: {{VALUE}}',
		// 		),
		// 		'condition'    => array(
		// 			'show_button' => 'yes'
		// 		)
		// 	)
		// );

		// $this->add_control(
		// 	'cart_icon_bg_color',
		// 	array(
		// 		'type'      => Controls_Manager::COLOR,
		// 		'label'     => esc_html__( 'Background Color', 'prime-addons-for-elementor' ),
		// 		'selectors' => array(
		// 			'{{WRAPPER}} .pae-carousel-button.buy' => 'background-color: {{VALUE}}',
		// 		),
		// 		'condition'    => array(
		// 			'show_button' => 'yes'
		// 		)
		// 	)
		// );

		// $this->add_control(
		// 	'view_icon',
		// 	[
		// 		'label' => esc_html__( 'View Icon', 'prime-addons-for-elementor' ),
		// 		'type' => Controls_Manager::HEADING,
		// 		'separator' => 'before'
		// 	]
		// );

		// $this->add_control(
		// 	'view_icon_color',
		// 	array(
		// 		'type'      => Controls_Manager::COLOR,
		// 		'label'     => esc_html__( 'Icon Color', 'prime-addons-for-elementor' ),
		// 		'selectors' => array(
		// 			'{{WRAPPER}} .pae-carousel-button.view, {{WRAPPER}} .pae-carousel-button.details' => 'color: {{VALUE}}',
		// 		)
		// 	)
		// );

		// $this->add_control(
		// 	'view_icon_bg_color',
		// 	array(
		// 		'type'      => Controls_Manager::COLOR,
		// 		'label'     => esc_html__( 'Background Color', 'prime-addons-for-elementor' ),
		// 		'selectors' => array(
		// 			'{{WRAPPER}} .pae-carousel-button.view, {{WRAPPER}} .pae-carousel-button.details' => 'background-color: {{VALUE}}',
		// 		),
		// 	)
		// );

		// $this->end_controls_section();

		do_action( 'pae_action_edd_product_carousel_after_icon_style_controls', $this );
	}

	protected function render() {
		global $post;

		$settings = $this->get_settings_for_display();

		$number  = $settings['number'];

		$columns    		= isset( $settings['columns'] ) ? $settings['columns'] : 3;
		$columns_tablet 	= isset( $settings['columns_tablet'] ) ? $settings['columns_tablet'] : 2;
		$columns_mobile 	= isset( $settings['columns_mobile'] ) ? $settings['columns_mobile'] : 1;

		$gap 				= isset( $settings['gap']['size'] ) ? $settings['gap']['size'] : 30;
		$gap_tablet			= isset( $settings['gap_tablet']['size'] ) ? $settings['gap_tablet']['size'] : 20;
		$gap_mobile			= isset( $settings['gap_mobile']['size'] ) ? $settings['gap_mobile']['size'] : 0;

		$products_categories = $settings['categories'];
		$order               = $settings['order'];
		$orderby             = $settings['orderby'];

		$autoplay        = $settings['carousel_autoplay'];
		$show_pagination = $settings['show_pagination'];
		$show_navigation = $settings['show_navigation'];

		$hover_effect = $settings['hover_effect'];
		$show_price   = $settings['show_price'];
		$show_button  = $settings['show_button'];
		$grid_style   = $settings['grid_style'];
		$boxed        = $settings['boxed'];
		$shape        = $settings['shape'];

		$carousel_id = 'pae-carousel-' . $this->get_id();

		$extra_class = '';

		$extra_class .= esc_attr( $shape );

		if ( $grid_style === 'overlay' ) {
			$extra_class .= ' overlay-content';
		}

		if ( $show_pagination === 'yes' ) {
			$extra_class .= ' has-pagination';
		}

		if ( $settings['navigation_visible_on_hover'] === 'yes' ) {
			$extra_class .= ' navigation-onhover';
		}

		$boxed_class = ( 'yes' === $settings['boxed'] ) ? 'boxed' : '';

		$hover_effect_class = ( 'yes' === $settings['hover_effect'] ) ? 'scale' : '';

		$renderHTML = '<div id="' . esc_attr( $carousel_id ) . '" data-columns-sm="' . esc_attr( $columns_mobile ) . '" data-columns-md="' . esc_attr( $columns_tablet ) . '" data-columns="' . esc_attr( $columns ) . '" data-gap-sm="' . esc_attr( $gap_mobile ) . '" data-gap-md="' . esc_attr( $gap_tablet ) . '" data-gap="' . esc_attr( $gap ) . '" data-autoplay="' . esc_attr( $autoplay ) . '" class="pae-carousel swiper-container ' . esc_attr( $extra_class ) . '">
        <div class="swiper-wrapper">';

			$params = array(
				'posts_per_page'    => absint( $number ),
				'post_type'         => 'download',
				'post_status'       => 'publish',
				'orderby'           => $orderby,
				'order'             => $order,
			);

			if ( ! empty( $products_categories ) ) {
				$params['tax_query'] = array(
					array(
						'taxonomy' => 'download_category',
						'field'    => 'term_id',
						'terms'    => (array) $products_categories,
					),
				);
			}

			$pae_carousel_query = new \WP_Query( $params );

			if ( $pae_carousel_query->have_posts() ) {
				while ( $pae_carousel_query->have_posts() ) :
					$pae_carousel_query->the_post();

					$buy_link = home_url( '/' ) . '?edd_action=add_to_cart&download_id=' . $post->ID;

					$renderHTML .= '<div class="swiper-slide pae-carousel-item pae-carousel-item-' . esc_attr( get_the_ID() ) . ' ' . esc_attr( $boxed_class ) . '">';
					$renderHTML .= '<div class="pae-carousel-thumbnail ' . $hover_effect_class . '">
										<img src="' . esc_url( get_the_post_thumbnail_url( get_the_ID(), esc_attr( $settings['image_size'] ) ) ) . '" alt=" ' . esc_attr( get_the_title() ) . ' " />
										<div class="overlay">';
					if ( $grid_style === 'overlay' ) {
						$renderHTML .= '<h4 class="pae-carousel-title"><a class="title" href="' . esc_url( get_the_permalink() ) . '">' . esc_attr( get_the_title() ) . '</a></h4>';
						if ( $show_price === 'yes' ) {
							$renderHTML .= '<div class="pae-carousel-price">' . edd_price( get_the_ID(), false ) . '</div>';
						}
						$renderHTML .= '<div class="button-area">';
						if ( $show_button === 'yes' ) {
							$renderHTML .= '<a href="' . esc_url( $buy_link ) . '" class="buy pae-carousel-button">' . PAE_Utils::get_icon( 'cart' ) . '</a>';
						}
						$renderHTML .= '<a href="' . esc_url( get_permalink() ) . '" class="view pae-carousel-button">' . PAE_Utils::get_icon( 'plus' ) . '</a>';
						$renderHTML .= '</div>';
					} else {
						$renderHTML .= '<div class="button-area">';
						$renderHTML .= '<a href="' . esc_url( get_permalink() ) . '" class="details pae-carousel-button">' . PAE_Utils::get_icon( 'plus' ) . '</a>';
						if ( $show_button === 'yes' ) {
							$renderHTML .= '<a href="' . esc_url( $buy_link ) . '" class="buy pae-carousel-button">' . PAE_Utils::get_icon( 'cart' ) . '</a>';
						}
						$renderHTML .= '</div>';
					}
						$renderHTML .= '</div>
									</div>';
					if ( $grid_style === 'default' ) {
						$renderHTML .= '<h4 class="pae-carousel-title"><a href="' . esc_url( get_permalink() ) . '">' . esc_html( get_the_title() ) . '</a></h4>';
						if ( $show_price === 'yes' ) {
							$renderHTML .= '<div class="pae-carousel-price">' . edd_price( get_the_ID(), false ) . '</div>';
						}
					}

					$renderHTML .= '</div>';

				endwhile;
				wp_reset_postdata();
			} else {
				$renderHTML .= '<div class="swiper-slide pae-carousel-item"><p>' . esc_html__( 'No Posts Found', 'prime-addons-for-elementor' ) . '</p></div>';
			}

			$renderHTML .= '</div>';

			if ( $show_pagination === 'yes' ) {
				$renderHTML .= '<div class="swiper-pagination"></div>';
			}

			if ( $show_navigation === 'yes'  ) {
				$renderHTML .= '<div class="swiper-button-next"><span>' . PAE_Utils::get_svg( 'icon-chevron-right' ) . '</span></div>';
				$renderHTML .= '<div class="swiper-button-prev"><span>' . PAE_Utils::get_svg( 'icon-chevron-left' ) . '</span></div>';
			}

		$renderHTML .= '</div>';

		echo $renderHTML;
	}
}
