<?php
/**
 * Widget: Flip Box
 *
 * @package Prime_Addons_Elementor
 */

namespace PrimeAddonsElementor\Elements\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\utils;
use Elementor\Core\Schemes\Color;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use PrimeAddonsElementor\Elements\Helpers\Utils as PAE_Utils;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Flip Box widget class.
 *
 * @since 1.0.0
 */
class Flip_Box_Widget extends Widget_Base {
	public function get_name() {
		return 'pae-flip-box';
	}

	public function get_title() {
		return esc_html__( 'Flip Box', 'prime-addons-for-elementor' );
	}

	public function get_icon() {
		return 'eicon-flip-box';
	}

	public function get_categories() {
		return array( 'prime-addons-elementor' );
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_flip_box',
			array(
				'label' => esc_html__( 'Settings', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_responsive_control(
			'height',
			array(
				'type'       => Controls_Manager::SLIDER,
				'label'      => esc_html__( 'Flip Box Height', 'prime-addons-for-elementor' ),
				'default'    => array(
					'size' => 400,
				),
				'range'      => array(
					'px' => array(
						'min'  => 200,
						'max'  => 800,
						'step' => 1,
					),
				),
				'size_units' => array( 'px' ),
				'selectors'  => array(
					'{{WRAPPER}} .pae-flip-box .front,{{WRAPPER}} .pae-flip-box .back' => 'height: {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'direction',
			array(
				'type'    => Controls_Manager::SELECT,
				'label'   => esc_html__( 'Flipping Direction', 'prime-addons-for-elementor' ),
				'default' => 'horizontal',
				'options' => array(
					'horizontal' => esc_html__( 'Flip X', 'prime-addons-for-elementor' ),
					'vertical'   => esc_html__( 'Flip Y', 'prime-addons-for-elementor' ),
				),
			)
		);

		$this->end_controls_section();

		// Content Tab: Front Content
		$this->start_controls_section(
			'section_flipbox_front_content',
			array(
				'label' => esc_html__( 'Front Content', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'front_icon',
			array(
				'type'        => Controls_Manager::ICONS,
				'label'       => esc_html__( 'Select Icon', 'prime-addons-for-elementor' ),
				'skin'        => 'inline',
				'label_block' => false,
			)
		);

		$this->add_control(
			'front_title',
			array(
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Title', 'prime-addons-for-elementor' ),
				'default' => esc_html__( 'Sample Title', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'front_content',
			array(
				'type'    => Controls_Manager::TEXTAREA,
				'label'   => esc_html__( 'Content', 'prime-addons-for-elementor' ),
				'default' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit.',
			)
		);

		$this->add_control(
			'front_bg_color',
			array(
				'label'     => esc_html__( 'Background Color', 'prime-addons-for-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#666',
				'selectors' => array(
					'{{WRAPPER}} .pae-flip-box .front,{{WRAPPER}} .pae-flip-box .front:after' => 'background-color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'front_single_image',
			array(
				'type'      => Controls_Manager::MEDIA,
				'label'     => esc_html__( 'Background Image', 'prime-addons-for-elementor' ),
				'selectors' => array(
					'{{WRAPPER}} .pae-flip-box .front' => 'background-image: url({{URL}});',
				),
			)
		);

		$this->end_controls_section();

		// Content Tab: Back Content
		$this->start_controls_section(
			'section_flipbox_back_content',
			array(
				'label' => esc_html__( 'Back Content', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'back_icon',
			array(
				'type'        => Controls_Manager::ICONS,
				'label'       => esc_html__( 'Select Icon', 'prime-addons-for-elementor' ),
				'skin'        => 'inline',
				'label_block' => false,
			)
		);

		$this->add_control(
			'back_title',
			array(
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Title', 'prime-addons-for-elementor' ),
				'default' => esc_html__( 'Sample Title', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'back_content',
			array(
				'type'    => Controls_Manager::TEXTAREA,
				'label'   => esc_html__( 'Content', 'prime-addons-for-elementor' ),
				'default' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit.',
			)
		);

		$this->add_control(
			'back_show_button',
			array(
				'label'        => esc_html__( 'Show Button?', 'prime-addons-for-elementor' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'yes',
				'label_on'     => esc_html__( 'Yes', 'prime-addons-for-elementor' ),
				'label_off'    => esc_html__( 'No', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'back_button_text',
			array(
				'label'       => esc_html__( 'Button Text', 'prime-addons-for-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__( 'Click here', 'prime-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Click here', 'prime-addons-for-elementor' ),
				'condition'   => array(
					'back_show_button' => 'yes',
				),
			)
		);

		$this->add_control(
			'back_button_url',
			array(
				'label'       => esc_html__( 'Button URL', 'prime-addons-for-elementor' ),
				'type'        => Controls_Manager::URL,
				'placeholder' => esc_html__( 'https://your-link.com', 'prime-addons-for-elementor' ),
				'default'     => array(
					'url' => '#',
				),
				'condition'   => array(
					'back_show_button' => 'yes',
				),
			)
		);

		$this->add_control(
			'back_bg_color',
			array(
				'label'     => esc_html__( 'Background Color', 'prime-addons-for-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#D4B840',
				'selectors' => array(
					'{{WRAPPER}} .pae-flip-box .back,{{WRAPPER}} .pae-flip-box .back:after' => 'background-color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'back_single_image',
			array(
				'type'      => Controls_Manager::MEDIA,
				'label'     => esc_html__( 'Background Image', 'prime-addons-for-elementor' ),
				'selectors' => array(
					'{{WRAPPER}} .pae-flip-box .back' => 'background-image: url({{URL}});',
				),
			)
		);
		$this->end_controls_section();

		// Style Tab: Front
		$this->start_controls_section(
			'section_flipbox_front_style',
			array(
				'label' => esc_html__( 'Front Style', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'front_icon_color',
			array(
				'label'     => esc_html__( 'Icon Color', 'prime-addons-for-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#ffffff',
				'selectors' => array(
					'{{WRAPPER}} .pae-flip-box .front .icon' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_responsive_control(
			'front_icon_size',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Icon Size', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-flip-box .front .icon' => 'font-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .pae-flip-box .front .icon svg' => 'width: {{SIZE}}{{UNIT}};',
				),
				'default'     => array(
					'size' => '48',
				),
				'size_units'  => array( 'em', 'px' ),
				'range'       => array(
					'em' => array(
						'min'  => 0,
						'max'  => 10,
						'step' => 0.1,
					),
					'px' => array(
						'min'  => 12,
						'max'  => 200,
						'step' => 1,
					),
				),
			)
		);

		$this->add_control(
			'front_title_color',
			array(
				'label'     => esc_html__( 'Title Color', 'prime-addons-for-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#ffffff',
				'selectors' => array(
					'{{WRAPPER}} .pae-flip-box .front .title' => 'color: {{VALUE}};',
				),
				'separator' => 'before',
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'typography_front_title',
				'label'    => esc_html__( 'Title Typography', 'prime-addons-for-elementor' ),
				'scheme'   => Typography::TYPOGRAPHY_2,
				'selector' => '{{WRAPPER}} .pae-flip-box .front .title',
			)
		);

		$this->add_responsive_control(
			'front_title_margin',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Margin Top', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-flip-box .front .title' => 'margin-top: {{SIZE}}{{UNIT}};',
				),
				'range'       => array(
					'px' => array(
						'min'  => 0,
						'max'  => 200,
						'step' => 1,
					),
				)
			)
		);

		$this->add_control(
			'front_content_color',
			array(
				'label'     => esc_html__( 'Content Text Color', 'prime-addons-for-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#ffffff',
				'selectors' => array(
					'{{WRAPPER}} .pae-flip-box .front .content' => 'color: {{VALUE}};',
				),
				'separator' => 'before',
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'typography_content',
				'label'    => esc_html__( 'Content Typography', 'prime-addons-for-elementor' ),
				'scheme'   => Typography::TYPOGRAPHY_2,
				'selector' => '{{WRAPPER}} .pae-flip-box .front .content',
			)
		);

		$this->end_controls_section();

		// Style Tab: Back
		$this->start_controls_section(
			'section_flipbox_back_style',
			array(
				'label' => esc_html__( 'Back Style', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'back_icon_color',
			array(
				'label'     => esc_html__( 'Icon Color', 'prime-addons-for-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#ffffff',
				'selectors' => array(
					'{{WRAPPER}} .pae-flip-box .back .icon' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_responsive_control(
			'back_icon_size',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Icon Size', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-flip-box .back .icon' => 'font-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .pae-flip-box .back .icon svg' => 'width: {{SIZE}}{{UNIT}};',
				),
				'default'     => array(
					'size' => '48',
				),
				'size_units'  => array( 'em', 'px' ),
				'range'       => array(
					'em' => array(
						'min'  => 0,
						'max'  => 10,
						'step' => 0.1,
					),
					'px' => array(
						'min'  => 12,
						'max'  => 200,
						'step' => 1,
					),
				),
			)
		);

		$this->add_control(
			'back_title_color',
			array(
				'label'     => esc_html__( 'Title Color', 'prime-addons-for-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#ffffff',
				'selectors' => array(
					'{{WRAPPER}} .pae-flip-box .back .title' => 'color: {{VALUE}};',
				),
				'separator' => 'before',

			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'typography_back_title',
				'label'    => esc_html__( 'Title Typography', 'prime-addons-for-elementor' ),
				'scheme'   => Typography::TYPOGRAPHY_2,
				'selector' => '{{WRAPPER}} .pae-flip-box .back .title',
			)
		);

		$this->add_responsive_control(
			'back_title_margin',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Margin Top', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-flip-box .back .title' => 'margin-top: {{SIZE}}{{UNIT}};',
				),
				'range'       => array(
					'px' => array(
						'min'  => 0,
						'max'  => 200,
						'step' => 1,
					),
				)
			)
		);

		$this->add_control(
			'back_content_color',
			array(
				'label'     => esc_html__( 'Content Text Color', 'prime-addons-for-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#ffffff',
				'selectors' => array(
					'{{WRAPPER}} .pae-flip-box .back .content' => 'color: {{VALUE}};',
				),
				'separator' => 'before',
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'typography_back_content',
				'label'    => esc_html__( 'Content Typography', 'prime-addons-for-elementor' ),
				'scheme'   => Typography::TYPOGRAPHY_2,
				'selector' => '{{WRAPPER}} .pae-flip-box .back .content',
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_flipbox_button_style',
			array(
				'label' => esc_html__( 'Button', 'prime-addons-for-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'back_show_button' => 'yes'
				],
			)
		);

		$this->start_controls_tabs( 'tabs_button_style' );

		$this->start_controls_tab(
			'tab_button_normal',
			array(
				'label' => esc_html__( 'Normal', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'button_text_color',
			array(
				'label'     => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .pae-flip-box .back .pae-button' => 'fill: {{VALUE}}; color: {{VALUE}};',
				),
				'condition' => [
					'back_show_button' => 'yes'
				],
			)
		);

		$this->add_control(
			'button_background_color',
			array(
				'label'     => esc_html__( 'Background Color', 'prime-addons-for-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .pae-flip-box .back .pae-button' => 'background-color: {{VALUE}};',
				),
				'condition' => [
					'back_show_button' => 'yes'
				],
			)
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			array(
				'name'      => 'button_border',
				'selector'  => '{{WRAPPER}} .pae-flip-box .back .pae-button',
				'condition' => [
					'back_show_button' => 'yes'
				],
			)
		);

		 $this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			array(
				'label' => esc_html__( 'Hover', 'prime-addons-for-elementor' ),
			)
		);

		$this->add_control(
			'button_hover_color',
			array(
				'label'     => esc_html__( 'Text Color', 'prime-addons-for-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .pae-flip-box .back .pae-button:hover' => 'fill: {{VALUE}}; color: {{VALUE}};',
				),
				'condition' => [
					'back_show_button' => 'yes'
				],
			)
		);

		$this->add_control(
			'button_background_hover_color',
			array(
				'label'     => esc_html__( 'Background Color', 'prime-addons-for-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .pae-flip-box .back .pae-button:hover' => 'background-color: {{VALUE}};',
				),
				'condition' => [
					'back_show_button' => 'yes'
				],
			)
		);

		$this->add_control(
			'button_hover_border_color',
			array(
				'label'     => esc_html__( 'Border Color', 'prime-addons-for-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => [
					'button_border_color!' => ''
				],
				'selectors' => array(
					'{{WRAPPER}} .pae-flip-box .back .pae-button:hover' => 'border-color: {{VALUE}};',
				),
				'condition' => [
					'back_show_button' => 'yes'
				],
			)
		);

		$this->add_control(
			'button_hover_animation',
			array(
				'label'    => esc_html__( 'Hover Animation', 'prime-addons-for-elementor' ),
				'type'     => Controls_Manager::HOVER_ANIMATION,
				'condition' => [
					'back_show_button' => 'yes'
				],
			)
		);

		 $this->end_controls_tab();

		 $this->end_controls_tabs();

		$this->add_control(
			'button_border_radius',
			array(
				'label'      => esc_html__( 'Border Radius', 'prime-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%' ),
				'selectors'  => array(
					'{{WRAPPER}} .pae-flip-box .back .pae-button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
				'separator' => 'before',
				'condition' => [
					'back_show_button' => 'yes'
				],
			)
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			array(
				'name'     => 'button_box_shadow',
				'selector' => '{{WRAPPER}} .pae-flip-box .back .pae-button',
				'condition' => [
					'back_show_button' => 'yes'
				],
			)
		);

		$this->add_responsive_control(
			'button_text_padding',
			array(
				'label'      => esc_html__( 'Padding', 'prime-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', 'em', '%' ),
				'selectors'  => array(
					'{{WRAPPER}} .pae-flip-box .back .pae-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
				'condition' => [
					'back_show_button' => 'yes'
				],
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'      => 'button_typography',
				'label'     => esc_html__( 'Typography', 'prime-addons-for-elementor' ),
				'scheme'    => Typography::TYPOGRAPHY_2,
				'selector'  => '{{WRAPPER}} .pae-flip-box .back .pae-button',
				'condition' => [
					'back_show_button' => 'yes'
				],
			)
		);

		$this->add_responsive_control(
			'button_margin',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Margin Top', 'prime-addons-for-elementor' ),
				'selectors'   => array(
					'{{WRAPPER}} .pae-flip-box .back .pae-button' => 'margin-top: {{SIZE}}{{UNIT}};',
				),
				'default'     => array(
					'size' => 15,
				),
				'range'       => array(
					'px' => array(
						'min'  => 0,
						'max'  => 200,
						'step' => 1,
					),
				),
				'condition' => [
					'back_show_button' => 'yes'
				],
			)
		);

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$height = $settings['height'];
		$button_hover_animation =   $settings['button_hover_animation'];

		$this->add_render_attribute( 'pae-flip-box', 'class', 'pae-flip-box' );
		$this->add_render_attribute( 'pae-flip-box', 'class', esc_attr( $settings['direction'] ) );

		// URL.
		if ( ! empty( $settings['back_button_url']['url'] ) ) {
			$this->add_link_attributes( 'back_button', $settings['back_button_url'] );
			$this->add_render_attribute( 'back_button', 'class', 'pae-button elementor-animation-' . $button_hover_animation );
		}
		?>
		<div <?php echo $this->get_render_attribute_string( 'pae-flip-box' ); ?> ontouchstart="this.classList.toggle('hover');">
			<?php
			$flipper_attrs = array(
				'class' => 'flipper',
			);

			$flipper_styles = '';

			if ( 'vertical' === $settings['direction'] ) {
				$flipper_styles = 'transform-origin: 100% ' . ( $height['size'] / 2 ) . 'px;-webkit-transform-origin: 100% ' . ( $height['size'] / 2 ) . 'px;-moz-transform-origin: 100% ' . ( $height['size'] / 2 ) . 'px;-ms-transform-origin: 100% ' . ( $height['size'] / 2 ) . 'px;'; // Half height.
			}

			if ( ! empty( $flipper_styles ) ) {
				$flipper_attrs['style'] = $flipper_styles;
			}
			?>
			<div <?php PAE_Utils::render_attr( $flipper_attrs ); ?>>
				<div class="front">
					<div class="inner">
						<?php if ( ! empty( $settings['front_icon']['value'] ) ) : ?>
							<div class="icon"><?php \Elementor\Icons_Manager::render_icon( $settings['front_icon'], array( 'aria-hidden' => 'true' ) ); ?></div>
						<?php endif; ?>

						<?php if ( ! empty( $settings['front_title'] ) ) : ?>
							<h2 class="title"><?php echo esc_html( $settings['front_title'] ); ?></h2>
						<?php endif; ?>

						<?php if ( ! empty( $settings['front_content'] ) ) : ?>
							<div class="content"><?php echo wp_kses_post( $settings['front_content'] ); ?></div>
						<?php endif; ?>
					</div><!-- .inner -->
				</div>
				<div class="back">
					<div class="inner">
						<?php if ( ! empty( $settings['back_icon']['value'] ) ) : ?>
							<div class="icon"><?php \Elementor\Icons_Manager::render_icon( $settings['back_icon'], array( 'aria-hidden' => 'true' ) ); ?></div>
						<?php endif; ?>

						<?php if ( ! empty( $settings['back_title'] ) ) : ?>
							<h2 class="title"><?php echo esc_html( $settings['back_title'] ); ?></h2>
						<?php endif; ?>

						<?php if ( ! empty( $settings['back_content'] ) ) : ?>
							<div class="content"><?php echo wp_kses_post( $settings['back_content'] ); ?></div>
						<?php endif; ?>

						<?php if ( 'yes' === $settings['back_show_button'] ) : ?>
							<div><a <?php echo $this->get_render_attribute_string( 'back_button' ); ?>><?php echo esc_html( $settings['back_button_text'] ); ?></a></div>
						<?php endif; ?>
					</div><!-- .inner -->
				</div>
			</div><!-- .flipper -->
		</div><!-- .pae-flip-box -->
		<?php
	}
}
